@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: Hayo Baan's Dist::Zilla configuration
-our $VERSION = '0.008'; # VERSION
+our $VERSION = '0.009'; # VERSION
 
 #pod =head1 DESCRIPTION
 #pod
@@ -34,8 +34,8 @@ our $VERSION = '0.008'; # VERSION
 #pod * L<MetaProvides::Class|Dist::Zilla::Plugin::MetaProvides::Class>
 #pod * L<ExecDir|Dist::Zilla::Plugin::ExecDir>
 #pod * L<ShareDir|Dist::Zilla::Plugin::ShareDir>
-#pod * L<MakeMaker|Dist::Zilla::Plugin::MakeMaker>
-#pod * L<ModuleBuild|Dist::Zilla::Plugin::ModuleBuild>
+#pod * L<MakeMaker|Dist::Zilla::Plugin::MakeMaker> (default)
+#pod * L<ModuleBuild|Dist::Zilla::Plugin::ModuleBuild> (optional)
 #pod * L<Manifest|Dist::Zilla::Plugin::Manifest>
 #pod * L<CopyFilesFromBuild|Dist::Zilla::Plugin::CopyFilesFromBuild>
 #pod * L<Run::AfterBuild|Dist::Zilla::Plugin::Run::AfterBuild>
@@ -346,6 +346,38 @@ has keep_version => (
     default => sub { $_[0]->payload->{keep_version} }
 );
 
+#pod =attr use_makemaker
+#pod
+#pod Uses MakeMaker as build method.
+#pod
+#pod Default: I<true>
+#pod
+#pod Note: When both C<use_makemaker> and C<use_modulebuild> are I<false>, MakeMaker will be used!
+#pod
+#pod =cut
+
+has use_makemaker => (
+    is      => 'rw',
+    isa     => 'Bool',
+    lazy    => 1,
+    default => sub { ($_[0]->payload->{use_makemaker} // 1) || !$_[0]->payload->{use_modulebuild} }
+);
+
+#pod =attr use_modulebuild
+#pod
+#pod Uses L<Module::Build> as build method.
+#pod
+#pod Default: I<false>
+#pod
+#pod =cut
+
+has use_modulebuild => (
+    is      => 'rw',
+    isa     => 'Bool',
+    lazy    => 1,
+    default => sub { $_[0]->payload->{use_modulebuild} }
+);
+
 #pod =attr run_after_build
 #pod
 #pod Specifies commands to run after the release has been built (but not yet released). Multiple
@@ -713,10 +745,14 @@ sub configure {
         'ExecDir',
         # Install content of share directory as sharedir
         'ShareDir',
-        # Build a Makefile.PL that uses ExtUtils::MakeMaker
-        [ 'MakeMaker', { default_jobs => 9 } ],
-        # Build a Build.PL that uses Module::Build
-        'ModuleBuild',
+        $self->use_makemaker ? (
+            # Build a Makefile.PL that uses ExtUtils::MakeMaker
+            [ 'MakeMaker', { default_jobs => 9 } ],
+        ) : (),
+        $self->use_modulebuild ? (
+            # Build a Build.PL that uses Module::Build
+            'ModuleBuild',
+        ) : (),
 
         # Add Manifest
         'Manifest',
@@ -874,7 +910,7 @@ Dist::Zilla::PluginBundle::Author::HAYOBAAN - Hayo Baan's Dist::Zilla configurat
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 DESCRIPTION
 
@@ -970,11 +1006,11 @@ L<ShareDir|Dist::Zilla::Plugin::ShareDir>
 
 =item *
 
-L<MakeMaker|Dist::Zilla::Plugin::MakeMaker>
+L<MakeMaker|Dist::Zilla::Plugin::MakeMaker> (default)
 
 =item *
 
-L<ModuleBuild|Dist::Zilla::Plugin::ModuleBuild>
+L<ModuleBuild|Dist::Zilla::Plugin::ModuleBuild> (optional)
 
 =item *
 
@@ -1268,6 +1304,20 @@ Note: Overrides L</make_minor_release>.
 
 Will keep the current version number the same when building/releasing.
 
+=head2 use_makemaker
+
+Uses MakeMaker as build method.
+
+Default: I<true>
+
+Note: When both C<use_makemaker> and C<use_modulebuild> are I<false>, MakeMaker will be used!
+
+=head2 use_modulebuild
+
+Uses L<Module::Build> as build method.
+
+Default: I<false>
+
 =head2 run_after_build
 
 Specifies commands to run after the release has been built (but not yet released). Multiple
